const config = require('config')

const getEmailCopy = ({
  emailType,
  titleText,
  expectedDate,
  targetUserName,
}) => {
  let upperContent, manuscriptText, lowerContent, paragraph
  let hasLink = true
  switch (emailType) {
    case 'reviewer-invitation':
      upperContent = `${titleText}, has been submitted for possible publication in Hindawi. As the Academic Editor handling the manuscript, I would be delighted if you would agree to review it and let me know whether you feel it is suitable for publication.`
      manuscriptText =
        "The manuscript's abstract, and author information is below to help you decide. Once you have agreed to review, you will be able to download the full article PDF."
      lowerContent = `If a potential conflict of interest exists between yourself and either the authors or
      the subject of the manuscript, please decline to handle the manuscript. If a conflict
      becomes apparent during the review process, please let me know at the earliest possible
      opportunity. For more information about our conflicts of interest policies, please
      see:
      <a href="https://www.hindawi.com/ethics/#coi">https://www.hindawi.com/ethics/#coi</a>.
      If you are able to review the manuscript, I would be grateful if you could submit your
      report by ${expectedDate}.`
      break
    case 'reviewer-resend-invitation':
      upperContent = `On ${expectedDate} I sent you a request to review ${titleText}, submitted for possible publication in Hindawi.
        I would be grateful if you would agree to review it and let me know whether you feel
        it is suitable for publication. If you are unable to review this manuscript then
        please decline to review. More details are available by clicking the link.`
      manuscriptText =
        "The manuscript's abstract, and author information is below to help you decide. Once you have agreed to review, you will be able to download the full article PDF."
      lowerContent =
        'I would like to thank you in advance for your help with the evaluation of this manuscript, since it would not be possible for us to run the journal without the help of our reviewers. I am looking forward to hearing from you.'
      break
    case 'reviewer-accepted':
      paragraph = `We are pleased to inform you that Dr. ${targetUserName} has agreed to review ${titleText}. You should receive the report by Dr. ${targetUserName} before ${expectedDate}. If you have any queries, or would like to send a reminder if you no report has been submitted, then please visit the manuscript details page to see the full review.`
      break
    case 'reviewer-declined':
      paragraph = `We regret to inform you that Dr. ${targetUserName} has declined to review ${titleText}. Please visit the manuscript details page to see if you need to invite any additional reviewers in order to reach a decision on the manuscript`
      break
    case 'reviewer-thank-you':
      paragraph = `Thank you for agreeing to review ${titleText}. You can view the full PDF file of the manuscript and post your review report using the following URL:`
      break
    case 'reviewer-cancel-invitation':
      paragraph = `You are no longer needed to review ${titleText}. If you have comments on this manuscript you believe the Editor should
        see, please email them to ${config.get(
          'mailer.from',
        )} as soon as possible. Thank you for your
        time and I hope you will consider reviewing for Hindawi again.`
      hasLink = false
      break
    case 'reviewer-new-account':
      paragraph = `You have been invited to review ${titleText}. In order to respond to the invitation, you need to confirm your account.`
      break
    default:
      throw new Error(`The ${emailType} email type is not defined.`)
  }

  return { upperContent, manuscriptText, lowerContent, paragraph, hasLink }
}

module.exports = {
  getEmailCopy,
}
